@@ -12,12 +12,13 @@ class Configuration(object):
 
     def __str__(self):
         configuration_string = 'PlugyPy Plugins Configuration:\n'
-        configuration_string += '\tWill Load All Plugins: {}\n'.format(
+        configuration_string += '\t\tWill Load All Plugins: {}\n'.format(
             self.will_load_all)
-
+        configuration_string += '\t\tPlugins:\n'
         for plugin in self.plugins:
-            configuration_string += '\t\tPlugin Name: {}\n'.format(plugin.name)
-            configuration_string += '\t\tIs Enabled: {}\n'.format(
+            configuration_string += '\t\t\tPlugin Name: {}\n'.format(
+                plugin.name)
+            configuration_string += '\t\t\tIs Enabled: {}\n'.format(
                 plugin.is_enabled)
 
         return configuration_string
